# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class ChartSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_column_tags': 'bool',
        'chart_default_color': 'str',
        'column_tags': 'str',
        'custom_tags': 'list[str]',
        'default_sort_column': 'str',
        'expected_data_spacing': 'int',
        'fixed_legend_display_stats': 'list[str]',
        'fixed_legend_enabled': 'bool',
        'fixed_legend_filter_field': 'str',
        'fixed_legend_filter_limit': 'int',
        'fixed_legend_filter_sort': 'str',
        'fixed_legend_hide_label': 'bool',
        'fixed_legend_position': 'str',
        'fixed_legend_show_metric_name': 'bool',
        'fixed_legend_show_source_name': 'bool',
        'fixed_legend_use_raw_stats': 'bool',
        'group_by_source': 'bool',
        'invert_dynamic_legend_hover_control': 'bool',
        'line_type': 'str',
        'max': 'float',
        'min': 'float',
        'num_tags': 'int',
        'plain_markdown_content': 'str',
        'show_hosts': 'bool',
        'show_labels': 'bool',
        'show_raw_values': 'bool',
        'sort_values_descending': 'bool',
        'sparkline_decimal_precision': 'int',
        'sparkline_display_color': 'str',
        'sparkline_display_font_size': 'str',
        'sparkline_display_horizontal_position': 'str',
        'sparkline_display_postfix': 'str',
        'sparkline_display_prefix': 'str',
        'sparkline_display_value_type': 'str',
        'sparkline_display_vertical_position': 'str',
        'sparkline_fill_color': 'str',
        'sparkline_line_color': 'str',
        'sparkline_size': 'str',
        'sparkline_value_color_map_apply_to': 'str',
        'sparkline_value_color_map_colors': 'list[str]',
        'sparkline_value_color_map_values': 'list[int]',
        'sparkline_value_color_map_values_v2': 'list[float]',
        'sparkline_value_text_map_text': 'list[str]',
        'sparkline_value_text_map_thresholds': 'list[float]',
        'stack_type': 'str',
        'tag_mode': 'str',
        'time_based_coloring': 'bool',
        'type': 'str',
        'window_size': 'int',
        'windowing': 'str',
        'xmax': 'float',
        'xmin': 'float',
        'y0_scale_si_by1024': 'bool',
        'y0_unit_autoscaling': 'bool',
        'y1_max': 'float',
        'y1_min': 'float',
        'y1_scale_si_by1024': 'bool',
        'y1_unit_autoscaling': 'bool',
        'y1_units': 'str',
        'ymax': 'float',
        'ymin': 'float'
    }

    attribute_map = {
        'auto_column_tags': 'autoColumnTags',
        'chart_default_color': 'chartDefaultColor',
        'column_tags': 'columnTags',
        'custom_tags': 'customTags',
        'default_sort_column': 'defaultSortColumn',
        'expected_data_spacing': 'expectedDataSpacing',
        'fixed_legend_display_stats': 'fixedLegendDisplayStats',
        'fixed_legend_enabled': 'fixedLegendEnabled',
        'fixed_legend_filter_field': 'fixedLegendFilterField',
        'fixed_legend_filter_limit': 'fixedLegendFilterLimit',
        'fixed_legend_filter_sort': 'fixedLegendFilterSort',
        'fixed_legend_hide_label': 'fixedLegendHideLabel',
        'fixed_legend_position': 'fixedLegendPosition',
        'fixed_legend_show_metric_name': 'fixedLegendShowMetricName',
        'fixed_legend_show_source_name': 'fixedLegendShowSourceName',
        'fixed_legend_use_raw_stats': 'fixedLegendUseRawStats',
        'group_by_source': 'groupBySource',
        'invert_dynamic_legend_hover_control': 'invertDynamicLegendHoverControl',
        'line_type': 'lineType',
        'max': 'max',
        'min': 'min',
        'num_tags': 'numTags',
        'plain_markdown_content': 'plainMarkdownContent',
        'show_hosts': 'showHosts',
        'show_labels': 'showLabels',
        'show_raw_values': 'showRawValues',
        'sort_values_descending': 'sortValuesDescending',
        'sparkline_decimal_precision': 'sparklineDecimalPrecision',
        'sparkline_display_color': 'sparklineDisplayColor',
        'sparkline_display_font_size': 'sparklineDisplayFontSize',
        'sparkline_display_horizontal_position': 'sparklineDisplayHorizontalPosition',
        'sparkline_display_postfix': 'sparklineDisplayPostfix',
        'sparkline_display_prefix': 'sparklineDisplayPrefix',
        'sparkline_display_value_type': 'sparklineDisplayValueType',
        'sparkline_display_vertical_position': 'sparklineDisplayVerticalPosition',
        'sparkline_fill_color': 'sparklineFillColor',
        'sparkline_line_color': 'sparklineLineColor',
        'sparkline_size': 'sparklineSize',
        'sparkline_value_color_map_apply_to': 'sparklineValueColorMapApplyTo',
        'sparkline_value_color_map_colors': 'sparklineValueColorMapColors',
        'sparkline_value_color_map_values': 'sparklineValueColorMapValues',
        'sparkline_value_color_map_values_v2': 'sparklineValueColorMapValuesV2',
        'sparkline_value_text_map_text': 'sparklineValueTextMapText',
        'sparkline_value_text_map_thresholds': 'sparklineValueTextMapThresholds',
        'stack_type': 'stackType',
        'tag_mode': 'tagMode',
        'time_based_coloring': 'timeBasedColoring',
        'type': 'type',
        'window_size': 'windowSize',
        'windowing': 'windowing',
        'xmax': 'xmax',
        'xmin': 'xmin',
        'y0_scale_si_by1024': 'y0ScaleSIBy1024',
        'y0_unit_autoscaling': 'y0UnitAutoscaling',
        'y1_max': 'y1Max',
        'y1_min': 'y1Min',
        'y1_scale_si_by1024': 'y1ScaleSIBy1024',
        'y1_unit_autoscaling': 'y1UnitAutoscaling',
        'y1_units': 'y1Units',
        'ymax': 'ymax',
        'ymin': 'ymin'
    }

    def __init__(self, auto_column_tags=None, chart_default_color=None, column_tags=None, custom_tags=None, default_sort_column=None, expected_data_spacing=None, fixed_legend_display_stats=None, fixed_legend_enabled=None, fixed_legend_filter_field=None, fixed_legend_filter_limit=None, fixed_legend_filter_sort=None, fixed_legend_hide_label=None, fixed_legend_position=None, fixed_legend_show_metric_name=None, fixed_legend_show_source_name=None, fixed_legend_use_raw_stats=None, group_by_source=None, invert_dynamic_legend_hover_control=None, line_type=None, max=None, min=None, num_tags=None, plain_markdown_content=None, show_hosts=None, show_labels=None, show_raw_values=None, sort_values_descending=None, sparkline_decimal_precision=None, sparkline_display_color=None, sparkline_display_font_size=None, sparkline_display_horizontal_position=None, sparkline_display_postfix=None, sparkline_display_prefix=None, sparkline_display_value_type=None, sparkline_display_vertical_position=None, sparkline_fill_color=None, sparkline_line_color=None, sparkline_size=None, sparkline_value_color_map_apply_to=None, sparkline_value_color_map_colors=None, sparkline_value_color_map_values=None, sparkline_value_color_map_values_v2=None, sparkline_value_text_map_text=None, sparkline_value_text_map_thresholds=None, stack_type=None, tag_mode=None, time_based_coloring=None, type=None, window_size=None, windowing=None, xmax=None, xmin=None, y0_scale_si_by1024=None, y0_unit_autoscaling=None, y1_max=None, y1_min=None, y1_scale_si_by1024=None, y1_unit_autoscaling=None, y1_units=None, ymax=None, ymin=None, _configuration=None):  # noqa: E501
        """ChartSettings - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auto_column_tags = None
        self._chart_default_color = None
        self._column_tags = None
        self._custom_tags = None
        self._default_sort_column = None
        self._expected_data_spacing = None
        self._fixed_legend_display_stats = None
        self._fixed_legend_enabled = None
        self._fixed_legend_filter_field = None
        self._fixed_legend_filter_limit = None
        self._fixed_legend_filter_sort = None
        self._fixed_legend_hide_label = None
        self._fixed_legend_position = None
        self._fixed_legend_show_metric_name = None
        self._fixed_legend_show_source_name = None
        self._fixed_legend_use_raw_stats = None
        self._group_by_source = None
        self._invert_dynamic_legend_hover_control = None
        self._line_type = None
        self._max = None
        self._min = None
        self._num_tags = None
        self._plain_markdown_content = None
        self._show_hosts = None
        self._show_labels = None
        self._show_raw_values = None
        self._sort_values_descending = None
        self._sparkline_decimal_precision = None
        self._sparkline_display_color = None
        self._sparkline_display_font_size = None
        self._sparkline_display_horizontal_position = None
        self._sparkline_display_postfix = None
        self._sparkline_display_prefix = None
        self._sparkline_display_value_type = None
        self._sparkline_display_vertical_position = None
        self._sparkline_fill_color = None
        self._sparkline_line_color = None
        self._sparkline_size = None
        self._sparkline_value_color_map_apply_to = None
        self._sparkline_value_color_map_colors = None
        self._sparkline_value_color_map_values = None
        self._sparkline_value_color_map_values_v2 = None
        self._sparkline_value_text_map_text = None
        self._sparkline_value_text_map_thresholds = None
        self._stack_type = None
        self._tag_mode = None
        self._time_based_coloring = None
        self._type = None
        self._window_size = None
        self._windowing = None
        self._xmax = None
        self._xmin = None
        self._y0_scale_si_by1024 = None
        self._y0_unit_autoscaling = None
        self._y1_max = None
        self._y1_min = None
        self._y1_scale_si_by1024 = None
        self._y1_unit_autoscaling = None
        self._y1_units = None
        self._ymax = None
        self._ymin = None
        self.discriminator = None

        if auto_column_tags is not None:
            self.auto_column_tags = auto_column_tags
        if chart_default_color is not None:
            self.chart_default_color = chart_default_color
        if column_tags is not None:
            self.column_tags = column_tags
        if custom_tags is not None:
            self.custom_tags = custom_tags
        if default_sort_column is not None:
            self.default_sort_column = default_sort_column
        if expected_data_spacing is not None:
            self.expected_data_spacing = expected_data_spacing
        if fixed_legend_display_stats is not None:
            self.fixed_legend_display_stats = fixed_legend_display_stats
        if fixed_legend_enabled is not None:
            self.fixed_legend_enabled = fixed_legend_enabled
        if fixed_legend_filter_field is not None:
            self.fixed_legend_filter_field = fixed_legend_filter_field
        if fixed_legend_filter_limit is not None:
            self.fixed_legend_filter_limit = fixed_legend_filter_limit
        if fixed_legend_filter_sort is not None:
            self.fixed_legend_filter_sort = fixed_legend_filter_sort
        if fixed_legend_hide_label is not None:
            self.fixed_legend_hide_label = fixed_legend_hide_label
        if fixed_legend_position is not None:
            self.fixed_legend_position = fixed_legend_position
        if fixed_legend_show_metric_name is not None:
            self.fixed_legend_show_metric_name = fixed_legend_show_metric_name
        if fixed_legend_show_source_name is not None:
            self.fixed_legend_show_source_name = fixed_legend_show_source_name
        if fixed_legend_use_raw_stats is not None:
            self.fixed_legend_use_raw_stats = fixed_legend_use_raw_stats
        if group_by_source is not None:
            self.group_by_source = group_by_source
        if invert_dynamic_legend_hover_control is not None:
            self.invert_dynamic_legend_hover_control = invert_dynamic_legend_hover_control
        if line_type is not None:
            self.line_type = line_type
        if max is not None:
            self.max = max
        if min is not None:
            self.min = min
        if num_tags is not None:
            self.num_tags = num_tags
        if plain_markdown_content is not None:
            self.plain_markdown_content = plain_markdown_content
        if show_hosts is not None:
            self.show_hosts = show_hosts
        if show_labels is not None:
            self.show_labels = show_labels
        if show_raw_values is not None:
            self.show_raw_values = show_raw_values
        if sort_values_descending is not None:
            self.sort_values_descending = sort_values_descending
        if sparkline_decimal_precision is not None:
            self.sparkline_decimal_precision = sparkline_decimal_precision
        if sparkline_display_color is not None:
            self.sparkline_display_color = sparkline_display_color
        if sparkline_display_font_size is not None:
            self.sparkline_display_font_size = sparkline_display_font_size
        if sparkline_display_horizontal_position is not None:
            self.sparkline_display_horizontal_position = sparkline_display_horizontal_position
        if sparkline_display_postfix is not None:
            self.sparkline_display_postfix = sparkline_display_postfix
        if sparkline_display_prefix is not None:
            self.sparkline_display_prefix = sparkline_display_prefix
        if sparkline_display_value_type is not None:
            self.sparkline_display_value_type = sparkline_display_value_type
        if sparkline_display_vertical_position is not None:
            self.sparkline_display_vertical_position = sparkline_display_vertical_position
        if sparkline_fill_color is not None:
            self.sparkline_fill_color = sparkline_fill_color
        if sparkline_line_color is not None:
            self.sparkline_line_color = sparkline_line_color
        if sparkline_size is not None:
            self.sparkline_size = sparkline_size
        if sparkline_value_color_map_apply_to is not None:
            self.sparkline_value_color_map_apply_to = sparkline_value_color_map_apply_to
        if sparkline_value_color_map_colors is not None:
            self.sparkline_value_color_map_colors = sparkline_value_color_map_colors
        if sparkline_value_color_map_values is not None:
            self.sparkline_value_color_map_values = sparkline_value_color_map_values
        if sparkline_value_color_map_values_v2 is not None:
            self.sparkline_value_color_map_values_v2 = sparkline_value_color_map_values_v2
        if sparkline_value_text_map_text is not None:
            self.sparkline_value_text_map_text = sparkline_value_text_map_text
        if sparkline_value_text_map_thresholds is not None:
            self.sparkline_value_text_map_thresholds = sparkline_value_text_map_thresholds
        if stack_type is not None:
            self.stack_type = stack_type
        if tag_mode is not None:
            self.tag_mode = tag_mode
        if time_based_coloring is not None:
            self.time_based_coloring = time_based_coloring
        self.type = type
        if window_size is not None:
            self.window_size = window_size
        if windowing is not None:
            self.windowing = windowing
        if xmax is not None:
            self.xmax = xmax
        if xmin is not None:
            self.xmin = xmin
        if y0_scale_si_by1024 is not None:
            self.y0_scale_si_by1024 = y0_scale_si_by1024
        if y0_unit_autoscaling is not None:
            self.y0_unit_autoscaling = y0_unit_autoscaling
        if y1_max is not None:
            self.y1_max = y1_max
        if y1_min is not None:
            self.y1_min = y1_min
        if y1_scale_si_by1024 is not None:
            self.y1_scale_si_by1024 = y1_scale_si_by1024
        if y1_unit_autoscaling is not None:
            self.y1_unit_autoscaling = y1_unit_autoscaling
        if y1_units is not None:
            self.y1_units = y1_units
        if ymax is not None:
            self.ymax = ymax
        if ymin is not None:
            self.ymin = ymin

    @property
    def auto_column_tags(self):
        """Gets the auto_column_tags of this ChartSettings.  # noqa: E501

        deprecated  # noqa: E501

        :return: The auto_column_tags of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._auto_column_tags

    @auto_column_tags.setter
    def auto_column_tags(self, auto_column_tags):
        """Sets the auto_column_tags of this ChartSettings.

        deprecated  # noqa: E501

        :param auto_column_tags: The auto_column_tags of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._auto_column_tags = auto_column_tags

    @property
    def chart_default_color(self):
        """Gets the chart_default_color of this ChartSettings.  # noqa: E501

        Default color that will be used in any chart rendering. Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :return: The chart_default_color of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._chart_default_color

    @chart_default_color.setter
    def chart_default_color(self, chart_default_color):
        """Sets the chart_default_color of this ChartSettings.

        Default color that will be used in any chart rendering. Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :param chart_default_color: The chart_default_color of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._chart_default_color = chart_default_color

    @property
    def column_tags(self):
        """Gets the column_tags of this ChartSettings.  # noqa: E501

        deprecated  # noqa: E501

        :return: The column_tags of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._column_tags

    @column_tags.setter
    def column_tags(self, column_tags):
        """Sets the column_tags of this ChartSettings.

        deprecated  # noqa: E501

        :param column_tags: The column_tags of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._column_tags = column_tags

    @property
    def custom_tags(self):
        """Gets the custom_tags of this ChartSettings.  # noqa: E501

        For the tabular view, a list of point tags to display when using the \"custom\" tag display mode  # noqa: E501

        :return: The custom_tags of this ChartSettings.  # noqa: E501
        :rtype: list[str]
        """
        return self._custom_tags

    @custom_tags.setter
    def custom_tags(self, custom_tags):
        """Sets the custom_tags of this ChartSettings.

        For the tabular view, a list of point tags to display when using the \"custom\" tag display mode  # noqa: E501

        :param custom_tags: The custom_tags of this ChartSettings.  # noqa: E501
        :type: list[str]
        """

        self._custom_tags = custom_tags

    @property
    def default_sort_column(self):
        """Gets the default_sort_column of this ChartSettings.  # noqa: E501

        For the tabular view, to select column for default sort  # noqa: E501

        :return: The default_sort_column of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._default_sort_column

    @default_sort_column.setter
    def default_sort_column(self, default_sort_column):
        """Sets the default_sort_column of this ChartSettings.

        For the tabular view, to select column for default sort  # noqa: E501

        :param default_sort_column: The default_sort_column of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._default_sort_column = default_sort_column

    @property
    def expected_data_spacing(self):
        """Gets the expected_data_spacing of this ChartSettings.  # noqa: E501

        Threshold (in seconds) for time delta between consecutive points in a series above which a dotted line will replace a solid line in line plots.  Default: 60s  # noqa: E501

        :return: The expected_data_spacing of this ChartSettings.  # noqa: E501
        :rtype: int
        """
        return self._expected_data_spacing

    @expected_data_spacing.setter
    def expected_data_spacing(self, expected_data_spacing):
        """Sets the expected_data_spacing of this ChartSettings.

        Threshold (in seconds) for time delta between consecutive points in a series above which a dotted line will replace a solid line in line plots.  Default: 60s  # noqa: E501

        :param expected_data_spacing: The expected_data_spacing of this ChartSettings.  # noqa: E501
        :type: int
        """

        self._expected_data_spacing = expected_data_spacing

    @property
    def fixed_legend_display_stats(self):
        """Gets the fixed_legend_display_stats of this ChartSettings.  # noqa: E501

        For a chart with a fixed legend, a list of statistics to display in the legend  # noqa: E501

        :return: The fixed_legend_display_stats of this ChartSettings.  # noqa: E501
        :rtype: list[str]
        """
        return self._fixed_legend_display_stats

    @fixed_legend_display_stats.setter
    def fixed_legend_display_stats(self, fixed_legend_display_stats):
        """Sets the fixed_legend_display_stats of this ChartSettings.

        For a chart with a fixed legend, a list of statistics to display in the legend  # noqa: E501

        :param fixed_legend_display_stats: The fixed_legend_display_stats of this ChartSettings.  # noqa: E501
        :type: list[str]
        """

        self._fixed_legend_display_stats = fixed_legend_display_stats

    @property
    def fixed_legend_enabled(self):
        """Gets the fixed_legend_enabled of this ChartSettings.  # noqa: E501

        Whether to enable a fixed tabular legend adjacent to the chart  # noqa: E501

        :return: The fixed_legend_enabled of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._fixed_legend_enabled

    @fixed_legend_enabled.setter
    def fixed_legend_enabled(self, fixed_legend_enabled):
        """Sets the fixed_legend_enabled of this ChartSettings.

        Whether to enable a fixed tabular legend adjacent to the chart  # noqa: E501

        :param fixed_legend_enabled: The fixed_legend_enabled of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._fixed_legend_enabled = fixed_legend_enabled

    @property
    def fixed_legend_filter_field(self):
        """Gets the fixed_legend_filter_field of this ChartSettings.  # noqa: E501

        Statistic to use for determining whether a series is displayed on the fixed legend  # noqa: E501

        :return: The fixed_legend_filter_field of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._fixed_legend_filter_field

    @fixed_legend_filter_field.setter
    def fixed_legend_filter_field(self, fixed_legend_filter_field):
        """Sets the fixed_legend_filter_field of this ChartSettings.

        Statistic to use for determining whether a series is displayed on the fixed legend  # noqa: E501

        :param fixed_legend_filter_field: The fixed_legend_filter_field of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["CURRENT", "MEAN", "MEDIAN", "SUM", "MIN", "MAX", "COUNT"]  # noqa: E501
        if (self._configuration.client_side_validation and
                fixed_legend_filter_field not in allowed_values):
            raise ValueError(
                "Invalid value for `fixed_legend_filter_field` ({0}), must be one of {1}"  # noqa: E501
                .format(fixed_legend_filter_field, allowed_values)
            )

        self._fixed_legend_filter_field = fixed_legend_filter_field

    @property
    def fixed_legend_filter_limit(self):
        """Gets the fixed_legend_filter_limit of this ChartSettings.  # noqa: E501

        Number of series to include in the fixed legend  # noqa: E501

        :return: The fixed_legend_filter_limit of this ChartSettings.  # noqa: E501
        :rtype: int
        """
        return self._fixed_legend_filter_limit

    @fixed_legend_filter_limit.setter
    def fixed_legend_filter_limit(self, fixed_legend_filter_limit):
        """Sets the fixed_legend_filter_limit of this ChartSettings.

        Number of series to include in the fixed legend  # noqa: E501

        :param fixed_legend_filter_limit: The fixed_legend_filter_limit of this ChartSettings.  # noqa: E501
        :type: int
        """

        self._fixed_legend_filter_limit = fixed_legend_filter_limit

    @property
    def fixed_legend_filter_sort(self):
        """Gets the fixed_legend_filter_sort of this ChartSettings.  # noqa: E501

        Whether to display \"Top\"- or \"Bottom\"-ranked series in the fixed legend  # noqa: E501

        :return: The fixed_legend_filter_sort of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._fixed_legend_filter_sort

    @fixed_legend_filter_sort.setter
    def fixed_legend_filter_sort(self, fixed_legend_filter_sort):
        """Sets the fixed_legend_filter_sort of this ChartSettings.

        Whether to display \"Top\"- or \"Bottom\"-ranked series in the fixed legend  # noqa: E501

        :param fixed_legend_filter_sort: The fixed_legend_filter_sort of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["TOP", "BOTTOM"]  # noqa: E501
        if (self._configuration.client_side_validation and
                fixed_legend_filter_sort not in allowed_values):
            raise ValueError(
                "Invalid value for `fixed_legend_filter_sort` ({0}), must be one of {1}"  # noqa: E501
                .format(fixed_legend_filter_sort, allowed_values)
            )

        self._fixed_legend_filter_sort = fixed_legend_filter_sort

    @property
    def fixed_legend_hide_label(self):
        """Gets the fixed_legend_hide_label of this ChartSettings.  # noqa: E501

        deprecated  # noqa: E501

        :return: The fixed_legend_hide_label of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._fixed_legend_hide_label

    @fixed_legend_hide_label.setter
    def fixed_legend_hide_label(self, fixed_legend_hide_label):
        """Sets the fixed_legend_hide_label of this ChartSettings.

        deprecated  # noqa: E501

        :param fixed_legend_hide_label: The fixed_legend_hide_label of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._fixed_legend_hide_label = fixed_legend_hide_label

    @property
    def fixed_legend_position(self):
        """Gets the fixed_legend_position of this ChartSettings.  # noqa: E501

        Where the fixed legend should be displayed with respect to the chart  # noqa: E501

        :return: The fixed_legend_position of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._fixed_legend_position

    @fixed_legend_position.setter
    def fixed_legend_position(self, fixed_legend_position):
        """Sets the fixed_legend_position of this ChartSettings.

        Where the fixed legend should be displayed with respect to the chart  # noqa: E501

        :param fixed_legend_position: The fixed_legend_position of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["RIGHT", "TOP", "LEFT", "BOTTOM"]  # noqa: E501
        if (self._configuration.client_side_validation and
                fixed_legend_position not in allowed_values):
            raise ValueError(
                "Invalid value for `fixed_legend_position` ({0}), must be one of {1}"  # noqa: E501
                .format(fixed_legend_position, allowed_values)
            )

        self._fixed_legend_position = fixed_legend_position

    @property
    def fixed_legend_show_metric_name(self):
        """Gets the fixed_legend_show_metric_name of this ChartSettings.  # noqa: E501

        Whether to display Metric Name fixed legend  # noqa: E501

        :return: The fixed_legend_show_metric_name of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._fixed_legend_show_metric_name

    @fixed_legend_show_metric_name.setter
    def fixed_legend_show_metric_name(self, fixed_legend_show_metric_name):
        """Sets the fixed_legend_show_metric_name of this ChartSettings.

        Whether to display Metric Name fixed legend  # noqa: E501

        :param fixed_legend_show_metric_name: The fixed_legend_show_metric_name of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._fixed_legend_show_metric_name = fixed_legend_show_metric_name

    @property
    def fixed_legend_show_source_name(self):
        """Gets the fixed_legend_show_source_name of this ChartSettings.  # noqa: E501

        Whether to display Source Name fixed legend  # noqa: E501

        :return: The fixed_legend_show_source_name of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._fixed_legend_show_source_name

    @fixed_legend_show_source_name.setter
    def fixed_legend_show_source_name(self, fixed_legend_show_source_name):
        """Sets the fixed_legend_show_source_name of this ChartSettings.

        Whether to display Source Name fixed legend  # noqa: E501

        :param fixed_legend_show_source_name: The fixed_legend_show_source_name of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._fixed_legend_show_source_name = fixed_legend_show_source_name

    @property
    def fixed_legend_use_raw_stats(self):
        """Gets the fixed_legend_use_raw_stats of this ChartSettings.  # noqa: E501

        If true, the legend uses non-summarized stats instead of summarized  # noqa: E501

        :return: The fixed_legend_use_raw_stats of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._fixed_legend_use_raw_stats

    @fixed_legend_use_raw_stats.setter
    def fixed_legend_use_raw_stats(self, fixed_legend_use_raw_stats):
        """Sets the fixed_legend_use_raw_stats of this ChartSettings.

        If true, the legend uses non-summarized stats instead of summarized  # noqa: E501

        :param fixed_legend_use_raw_stats: The fixed_legend_use_raw_stats of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._fixed_legend_use_raw_stats = fixed_legend_use_raw_stats

    @property
    def group_by_source(self):
        """Gets the group_by_source of this ChartSettings.  # noqa: E501

        For the tabular view, whether to group multi metrics into a single row by a common source.  If false, each metric for each source is displayed in its own row.  If true, multiple metrics for the same host will be displayed as different columns in the same row  # noqa: E501

        :return: The group_by_source of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._group_by_source

    @group_by_source.setter
    def group_by_source(self, group_by_source):
        """Sets the group_by_source of this ChartSettings.

        For the tabular view, whether to group multi metrics into a single row by a common source.  If false, each metric for each source is displayed in its own row.  If true, multiple metrics for the same host will be displayed as different columns in the same row  # noqa: E501

        :param group_by_source: The group_by_source of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._group_by_source = group_by_source

    @property
    def invert_dynamic_legend_hover_control(self):
        """Gets the invert_dynamic_legend_hover_control of this ChartSettings.  # noqa: E501

        Whether to disable the display of the floating legend (but reenable it when the ctrl-key is pressed)  # noqa: E501

        :return: The invert_dynamic_legend_hover_control of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._invert_dynamic_legend_hover_control

    @invert_dynamic_legend_hover_control.setter
    def invert_dynamic_legend_hover_control(self, invert_dynamic_legend_hover_control):
        """Sets the invert_dynamic_legend_hover_control of this ChartSettings.

        Whether to disable the display of the floating legend (but reenable it when the ctrl-key is pressed)  # noqa: E501

        :param invert_dynamic_legend_hover_control: The invert_dynamic_legend_hover_control of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._invert_dynamic_legend_hover_control = invert_dynamic_legend_hover_control

    @property
    def line_type(self):
        """Gets the line_type of this ChartSettings.  # noqa: E501

        Plot interpolation type.  linear is default  # noqa: E501

        :return: The line_type of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._line_type

    @line_type.setter
    def line_type(self, line_type):
        """Sets the line_type of this ChartSettings.

        Plot interpolation type.  linear is default  # noqa: E501

        :param line_type: The line_type of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["linear", "step-before", "step-after", "basis", "cardinal", "monotone"]  # noqa: E501
        if (self._configuration.client_side_validation and
                line_type not in allowed_values):
            raise ValueError(
                "Invalid value for `line_type` ({0}), must be one of {1}"  # noqa: E501
                .format(line_type, allowed_values)
            )

        self._line_type = line_type

    @property
    def max(self):
        """Gets the max of this ChartSettings.  # noqa: E501

        Max value of Y-axis.  Set to null or leave blank for auto  # noqa: E501

        :return: The max of this ChartSettings.  # noqa: E501
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this ChartSettings.

        Max value of Y-axis.  Set to null or leave blank for auto  # noqa: E501

        :param max: The max of this ChartSettings.  # noqa: E501
        :type: float
        """

        self._max = max

    @property
    def min(self):
        """Gets the min of this ChartSettings.  # noqa: E501

        Min value of Y-axis.  Set to null or leave blank for auto  # noqa: E501

        :return: The min of this ChartSettings.  # noqa: E501
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this ChartSettings.

        Min value of Y-axis.  Set to null or leave blank for auto  # noqa: E501

        :param min: The min of this ChartSettings.  # noqa: E501
        :type: float
        """

        self._min = min

    @property
    def num_tags(self):
        """Gets the num_tags of this ChartSettings.  # noqa: E501

        For the tabular view, how many point tags to display  # noqa: E501

        :return: The num_tags of this ChartSettings.  # noqa: E501
        :rtype: int
        """
        return self._num_tags

    @num_tags.setter
    def num_tags(self, num_tags):
        """Sets the num_tags of this ChartSettings.

        For the tabular view, how many point tags to display  # noqa: E501

        :param num_tags: The num_tags of this ChartSettings.  # noqa: E501
        :type: int
        """

        self._num_tags = num_tags

    @property
    def plain_markdown_content(self):
        """Gets the plain_markdown_content of this ChartSettings.  # noqa: E501

        The Markdown content for a Markdown display, in plain text.  Use this field instead of `markdownContent`.  # noqa: E501

        :return: The plain_markdown_content of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._plain_markdown_content

    @plain_markdown_content.setter
    def plain_markdown_content(self, plain_markdown_content):
        """Sets the plain_markdown_content of this ChartSettings.

        The Markdown content for a Markdown display, in plain text.  Use this field instead of `markdownContent`.  # noqa: E501

        :param plain_markdown_content: The plain_markdown_content of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._plain_markdown_content = plain_markdown_content

    @property
    def show_hosts(self):
        """Gets the show_hosts of this ChartSettings.  # noqa: E501

        For the tabular view, whether to display sources.  Default: true  # noqa: E501

        :return: The show_hosts of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._show_hosts

    @show_hosts.setter
    def show_hosts(self, show_hosts):
        """Sets the show_hosts of this ChartSettings.

        For the tabular view, whether to display sources.  Default: true  # noqa: E501

        :param show_hosts: The show_hosts of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._show_hosts = show_hosts

    @property
    def show_labels(self):
        """Gets the show_labels of this ChartSettings.  # noqa: E501

        For the tabular view, whether to display labels.  Default: true  # noqa: E501

        :return: The show_labels of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._show_labels

    @show_labels.setter
    def show_labels(self, show_labels):
        """Sets the show_labels of this ChartSettings.

        For the tabular view, whether to display labels.  Default: true  # noqa: E501

        :param show_labels: The show_labels of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._show_labels = show_labels

    @property
    def show_raw_values(self):
        """Gets the show_raw_values of this ChartSettings.  # noqa: E501

        For the tabular view, whether to display raw values.  Default: false  # noqa: E501

        :return: The show_raw_values of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._show_raw_values

    @show_raw_values.setter
    def show_raw_values(self, show_raw_values):
        """Sets the show_raw_values of this ChartSettings.

        For the tabular view, whether to display raw values.  Default: false  # noqa: E501

        :param show_raw_values: The show_raw_values of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._show_raw_values = show_raw_values

    @property
    def sort_values_descending(self):
        """Gets the sort_values_descending of this ChartSettings.  # noqa: E501

        For the tabular view, whether to display display values in descending order.  Default: false  # noqa: E501

        :return: The sort_values_descending of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._sort_values_descending

    @sort_values_descending.setter
    def sort_values_descending(self, sort_values_descending):
        """Sets the sort_values_descending of this ChartSettings.

        For the tabular view, whether to display display values in descending order.  Default: false  # noqa: E501

        :param sort_values_descending: The sort_values_descending of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._sort_values_descending = sort_values_descending

    @property
    def sparkline_decimal_precision(self):
        """Gets the sparkline_decimal_precision of this ChartSettings.  # noqa: E501

        For the single stat view, the decimal precision of the displayed number  # noqa: E501

        :return: The sparkline_decimal_precision of this ChartSettings.  # noqa: E501
        :rtype: int
        """
        return self._sparkline_decimal_precision

    @sparkline_decimal_precision.setter
    def sparkline_decimal_precision(self, sparkline_decimal_precision):
        """Sets the sparkline_decimal_precision of this ChartSettings.

        For the single stat view, the decimal precision of the displayed number  # noqa: E501

        :param sparkline_decimal_precision: The sparkline_decimal_precision of this ChartSettings.  # noqa: E501
        :type: int
        """

        self._sparkline_decimal_precision = sparkline_decimal_precision

    @property
    def sparkline_display_color(self):
        """Gets the sparkline_display_color of this ChartSettings.  # noqa: E501

        For the single stat view, the color of the displayed text (when not dynamically determined). Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :return: The sparkline_display_color of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_display_color

    @sparkline_display_color.setter
    def sparkline_display_color(self, sparkline_display_color):
        """Sets the sparkline_display_color of this ChartSettings.

        For the single stat view, the color of the displayed text (when not dynamically determined). Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :param sparkline_display_color: The sparkline_display_color of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._sparkline_display_color = sparkline_display_color

    @property
    def sparkline_display_font_size(self):
        """Gets the sparkline_display_font_size of this ChartSettings.  # noqa: E501

        For the single stat view, the font size of the displayed text, in percent  # noqa: E501

        :return: The sparkline_display_font_size of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_display_font_size

    @sparkline_display_font_size.setter
    def sparkline_display_font_size(self, sparkline_display_font_size):
        """Sets the sparkline_display_font_size of this ChartSettings.

        For the single stat view, the font size of the displayed text, in percent  # noqa: E501

        :param sparkline_display_font_size: The sparkline_display_font_size of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._sparkline_display_font_size = sparkline_display_font_size

    @property
    def sparkline_display_horizontal_position(self):
        """Gets the sparkline_display_horizontal_position of this ChartSettings.  # noqa: E501

        For the single stat view, the horizontal position of the displayed text  # noqa: E501

        :return: The sparkline_display_horizontal_position of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_display_horizontal_position

    @sparkline_display_horizontal_position.setter
    def sparkline_display_horizontal_position(self, sparkline_display_horizontal_position):
        """Sets the sparkline_display_horizontal_position of this ChartSettings.

        For the single stat view, the horizontal position of the displayed text  # noqa: E501

        :param sparkline_display_horizontal_position: The sparkline_display_horizontal_position of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["MIDDLE", "LEFT", "RIGHT"]  # noqa: E501
        if (self._configuration.client_side_validation and
                sparkline_display_horizontal_position not in allowed_values):
            raise ValueError(
                "Invalid value for `sparkline_display_horizontal_position` ({0}), must be one of {1}"  # noqa: E501
                .format(sparkline_display_horizontal_position, allowed_values)
            )

        self._sparkline_display_horizontal_position = sparkline_display_horizontal_position

    @property
    def sparkline_display_postfix(self):
        """Gets the sparkline_display_postfix of this ChartSettings.  # noqa: E501

        For the single stat view, a string to append to the displayed text  # noqa: E501

        :return: The sparkline_display_postfix of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_display_postfix

    @sparkline_display_postfix.setter
    def sparkline_display_postfix(self, sparkline_display_postfix):
        """Sets the sparkline_display_postfix of this ChartSettings.

        For the single stat view, a string to append to the displayed text  # noqa: E501

        :param sparkline_display_postfix: The sparkline_display_postfix of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._sparkline_display_postfix = sparkline_display_postfix

    @property
    def sparkline_display_prefix(self):
        """Gets the sparkline_display_prefix of this ChartSettings.  # noqa: E501

        For the single stat view, a string to add before the displayed text  # noqa: E501

        :return: The sparkline_display_prefix of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_display_prefix

    @sparkline_display_prefix.setter
    def sparkline_display_prefix(self, sparkline_display_prefix):
        """Sets the sparkline_display_prefix of this ChartSettings.

        For the single stat view, a string to add before the displayed text  # noqa: E501

        :param sparkline_display_prefix: The sparkline_display_prefix of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._sparkline_display_prefix = sparkline_display_prefix

    @property
    def sparkline_display_value_type(self):
        """Gets the sparkline_display_value_type of this ChartSettings.  # noqa: E501

        For the single stat view, whether to display the name of the query or the value of query  # noqa: E501

        :return: The sparkline_display_value_type of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_display_value_type

    @sparkline_display_value_type.setter
    def sparkline_display_value_type(self, sparkline_display_value_type):
        """Sets the sparkline_display_value_type of this ChartSettings.

        For the single stat view, whether to display the name of the query or the value of query  # noqa: E501

        :param sparkline_display_value_type: The sparkline_display_value_type of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["VALUE", "LABEL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                sparkline_display_value_type not in allowed_values):
            raise ValueError(
                "Invalid value for `sparkline_display_value_type` ({0}), must be one of {1}"  # noqa: E501
                .format(sparkline_display_value_type, allowed_values)
            )

        self._sparkline_display_value_type = sparkline_display_value_type

    @property
    def sparkline_display_vertical_position(self):
        """Gets the sparkline_display_vertical_position of this ChartSettings.  # noqa: E501

        deprecated  # noqa: E501

        :return: The sparkline_display_vertical_position of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_display_vertical_position

    @sparkline_display_vertical_position.setter
    def sparkline_display_vertical_position(self, sparkline_display_vertical_position):
        """Sets the sparkline_display_vertical_position of this ChartSettings.

        deprecated  # noqa: E501

        :param sparkline_display_vertical_position: The sparkline_display_vertical_position of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._sparkline_display_vertical_position = sparkline_display_vertical_position

    @property
    def sparkline_fill_color(self):
        """Gets the sparkline_fill_color of this ChartSettings.  # noqa: E501

        For the single stat view, the color of the background fill. Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :return: The sparkline_fill_color of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_fill_color

    @sparkline_fill_color.setter
    def sparkline_fill_color(self, sparkline_fill_color):
        """Sets the sparkline_fill_color of this ChartSettings.

        For the single stat view, the color of the background fill. Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :param sparkline_fill_color: The sparkline_fill_color of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._sparkline_fill_color = sparkline_fill_color

    @property
    def sparkline_line_color(self):
        """Gets the sparkline_line_color of this ChartSettings.  # noqa: E501

        For the single stat view, the color of the line. Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :return: The sparkline_line_color of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_line_color

    @sparkline_line_color.setter
    def sparkline_line_color(self, sparkline_line_color):
        """Sets the sparkline_line_color of this ChartSettings.

        For the single stat view, the color of the line. Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :param sparkline_line_color: The sparkline_line_color of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._sparkline_line_color = sparkline_line_color

    @property
    def sparkline_size(self):
        """Gets the sparkline_size of this ChartSettings.  # noqa: E501

        For the single stat view, a misleadingly named property.  This determines whether the sparkline of the statistic is displayed in the chart BACKGROUND, BOTTOM, or NONE  # noqa: E501

        :return: The sparkline_size of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_size

    @sparkline_size.setter
    def sparkline_size(self, sparkline_size):
        """Sets the sparkline_size of this ChartSettings.

        For the single stat view, a misleadingly named property.  This determines whether the sparkline of the statistic is displayed in the chart BACKGROUND, BOTTOM, or NONE  # noqa: E501

        :param sparkline_size: The sparkline_size of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["BACKGROUND", "BOTTOM", "NONE"]  # noqa: E501
        if (self._configuration.client_side_validation and
                sparkline_size not in allowed_values):
            raise ValueError(
                "Invalid value for `sparkline_size` ({0}), must be one of {1}"  # noqa: E501
                .format(sparkline_size, allowed_values)
            )

        self._sparkline_size = sparkline_size

    @property
    def sparkline_value_color_map_apply_to(self):
        """Gets the sparkline_value_color_map_apply_to of this ChartSettings.  # noqa: E501

        For the single stat view, whether to apply dynamic color settings to the displayed TEXT or BACKGROUND  # noqa: E501

        :return: The sparkline_value_color_map_apply_to of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._sparkline_value_color_map_apply_to

    @sparkline_value_color_map_apply_to.setter
    def sparkline_value_color_map_apply_to(self, sparkline_value_color_map_apply_to):
        """Sets the sparkline_value_color_map_apply_to of this ChartSettings.

        For the single stat view, whether to apply dynamic color settings to the displayed TEXT or BACKGROUND  # noqa: E501

        :param sparkline_value_color_map_apply_to: The sparkline_value_color_map_apply_to of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["TEXT", "BACKGROUND"]  # noqa: E501
        if (self._configuration.client_side_validation and
                sparkline_value_color_map_apply_to not in allowed_values):
            raise ValueError(
                "Invalid value for `sparkline_value_color_map_apply_to` ({0}), must be one of {1}"  # noqa: E501
                .format(sparkline_value_color_map_apply_to, allowed_values)
            )

        self._sparkline_value_color_map_apply_to = sparkline_value_color_map_apply_to

    @property
    def sparkline_value_color_map_colors(self):
        """Gets the sparkline_value_color_map_colors of this ChartSettings.  # noqa: E501

        For the single stat view, a list of colors that differing query values map to.  Must contain one more element than sparklineValueColorMapValuesV2. Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :return: The sparkline_value_color_map_colors of this ChartSettings.  # noqa: E501
        :rtype: list[str]
        """
        return self._sparkline_value_color_map_colors

    @sparkline_value_color_map_colors.setter
    def sparkline_value_color_map_colors(self, sparkline_value_color_map_colors):
        """Sets the sparkline_value_color_map_colors of this ChartSettings.

        For the single stat view, a list of colors that differing query values map to.  Must contain one more element than sparklineValueColorMapValuesV2. Values should be in \"rgba(&lt;rval&gt;, &lt;gval&gt;, &lt;bval&gt;, &lt;aval&gt;)\" format  # noqa: E501

        :param sparkline_value_color_map_colors: The sparkline_value_color_map_colors of this ChartSettings.  # noqa: E501
        :type: list[str]
        """

        self._sparkline_value_color_map_colors = sparkline_value_color_map_colors

    @property
    def sparkline_value_color_map_values(self):
        """Gets the sparkline_value_color_map_values of this ChartSettings.  # noqa: E501

        deprecated  # noqa: E501

        :return: The sparkline_value_color_map_values of this ChartSettings.  # noqa: E501
        :rtype: list[int]
        """
        return self._sparkline_value_color_map_values

    @sparkline_value_color_map_values.setter
    def sparkline_value_color_map_values(self, sparkline_value_color_map_values):
        """Sets the sparkline_value_color_map_values of this ChartSettings.

        deprecated  # noqa: E501

        :param sparkline_value_color_map_values: The sparkline_value_color_map_values of this ChartSettings.  # noqa: E501
        :type: list[int]
        """

        self._sparkline_value_color_map_values = sparkline_value_color_map_values

    @property
    def sparkline_value_color_map_values_v2(self):
        """Gets the sparkline_value_color_map_values_v2 of this ChartSettings.  # noqa: E501

        For the single stat view, a list of boundaries for mapping different query values to colors.  Must contain one less element than sparklineValueColorMapColors  # noqa: E501

        :return: The sparkline_value_color_map_values_v2 of this ChartSettings.  # noqa: E501
        :rtype: list[float]
        """
        return self._sparkline_value_color_map_values_v2

    @sparkline_value_color_map_values_v2.setter
    def sparkline_value_color_map_values_v2(self, sparkline_value_color_map_values_v2):
        """Sets the sparkline_value_color_map_values_v2 of this ChartSettings.

        For the single stat view, a list of boundaries for mapping different query values to colors.  Must contain one less element than sparklineValueColorMapColors  # noqa: E501

        :param sparkline_value_color_map_values_v2: The sparkline_value_color_map_values_v2 of this ChartSettings.  # noqa: E501
        :type: list[float]
        """

        self._sparkline_value_color_map_values_v2 = sparkline_value_color_map_values_v2

    @property
    def sparkline_value_text_map_text(self):
        """Gets the sparkline_value_text_map_text of this ChartSettings.  # noqa: E501

        For the single stat view, a list of display text values that different query values map to.  Must contain one more element than sparklineValueTextMapThresholds  # noqa: E501

        :return: The sparkline_value_text_map_text of this ChartSettings.  # noqa: E501
        :rtype: list[str]
        """
        return self._sparkline_value_text_map_text

    @sparkline_value_text_map_text.setter
    def sparkline_value_text_map_text(self, sparkline_value_text_map_text):
        """Sets the sparkline_value_text_map_text of this ChartSettings.

        For the single stat view, a list of display text values that different query values map to.  Must contain one more element than sparklineValueTextMapThresholds  # noqa: E501

        :param sparkline_value_text_map_text: The sparkline_value_text_map_text of this ChartSettings.  # noqa: E501
        :type: list[str]
        """

        self._sparkline_value_text_map_text = sparkline_value_text_map_text

    @property
    def sparkline_value_text_map_thresholds(self):
        """Gets the sparkline_value_text_map_thresholds of this ChartSettings.  # noqa: E501

        For the single stat view, a list of threshold boundaries for mapping different query values to display text. Must contain one less element than sparklineValueTextMapText  # noqa: E501

        :return: The sparkline_value_text_map_thresholds of this ChartSettings.  # noqa: E501
        :rtype: list[float]
        """
        return self._sparkline_value_text_map_thresholds

    @sparkline_value_text_map_thresholds.setter
    def sparkline_value_text_map_thresholds(self, sparkline_value_text_map_thresholds):
        """Sets the sparkline_value_text_map_thresholds of this ChartSettings.

        For the single stat view, a list of threshold boundaries for mapping different query values to display text. Must contain one less element than sparklineValueTextMapText  # noqa: E501

        :param sparkline_value_text_map_thresholds: The sparkline_value_text_map_thresholds of this ChartSettings.  # noqa: E501
        :type: list[float]
        """

        self._sparkline_value_text_map_thresholds = sparkline_value_text_map_thresholds

    @property
    def stack_type(self):
        """Gets the stack_type of this ChartSettings.  # noqa: E501

        Type of stacked chart (applicable only if chart type is stacked).  zero (default) means stacked from y=0.  expand means Normalized from 0 to 1.  wiggle means Minimize weighted changes. silhouette means to Center the Stream  # noqa: E501

        :return: The stack_type of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._stack_type

    @stack_type.setter
    def stack_type(self, stack_type):
        """Sets the stack_type of this ChartSettings.

        Type of stacked chart (applicable only if chart type is stacked).  zero (default) means stacked from y=0.  expand means Normalized from 0 to 1.  wiggle means Minimize weighted changes. silhouette means to Center the Stream  # noqa: E501

        :param stack_type: The stack_type of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["zero", "expand", "wiggle", "silhouette", "bars"]  # noqa: E501
        if (self._configuration.client_side_validation and
                stack_type not in allowed_values):
            raise ValueError(
                "Invalid value for `stack_type` ({0}), must be one of {1}"  # noqa: E501
                .format(stack_type, allowed_values)
            )

        self._stack_type = stack_type

    @property
    def tag_mode(self):
        """Gets the tag_mode of this ChartSettings.  # noqa: E501

        For the tabular view, which mode to use to determine which point tags to display  # noqa: E501

        :return: The tag_mode of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._tag_mode

    @tag_mode.setter
    def tag_mode(self, tag_mode):
        """Sets the tag_mode of this ChartSettings.

        For the tabular view, which mode to use to determine which point tags to display  # noqa: E501

        :param tag_mode: The tag_mode of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["all", "top", "custom"]  # noqa: E501
        if (self._configuration.client_side_validation and
                tag_mode not in allowed_values):
            raise ValueError(
                "Invalid value for `tag_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(tag_mode, allowed_values)
            )

        self._tag_mode = tag_mode

    @property
    def time_based_coloring(self):
        """Gets the time_based_coloring of this ChartSettings.  # noqa: E501

        For x-y scatterplots, whether to color more recent points as darker than older points. Default: false  # noqa: E501

        :return: The time_based_coloring of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._time_based_coloring

    @time_based_coloring.setter
    def time_based_coloring(self, time_based_coloring):
        """Sets the time_based_coloring of this ChartSettings.

        For x-y scatterplots, whether to color more recent points as darker than older points. Default: false  # noqa: E501

        :param time_based_coloring: The time_based_coloring of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._time_based_coloring = time_based_coloring

    @property
    def type(self):
        """Gets the type of this ChartSettings.  # noqa: E501

        Chart Type.  'line' refers to the Line Plot, 'scatter' to the Point Plot, 'stacked-area' to the Stacked Area plot, 'table' to the Tabular View, 'scatterploy-xy' to Scatter Plot, 'markdown-widget' to the Markdown display, and 'sparkline' to the Single Stat view  # noqa: E501

        :return: The type of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ChartSettings.

        Chart Type.  'line' refers to the Line Plot, 'scatter' to the Point Plot, 'stacked-area' to the Stacked Area plot, 'table' to the Tabular View, 'scatterploy-xy' to Scatter Plot, 'markdown-widget' to the Markdown display, and 'sparkline' to the Single Stat view  # noqa: E501

        :param type: The type of this ChartSettings.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["line", "scatterplot", "stacked-area", "stacked-column", "table", "scatterplot-xy", "markdown-widget", "sparkline", "globe", "nodemap", "top-k", "status-list", "histogram", "heatmap", "gauge", "pie"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def window_size(self):
        """Gets the window_size of this ChartSettings.  # noqa: E501

        Width, in minutes, of the time window to use for \"last\" windowing  # noqa: E501

        :return: The window_size of this ChartSettings.  # noqa: E501
        :rtype: int
        """
        return self._window_size

    @window_size.setter
    def window_size(self, window_size):
        """Sets the window_size of this ChartSettings.

        Width, in minutes, of the time window to use for \"last\" windowing  # noqa: E501

        :param window_size: The window_size of this ChartSettings.  # noqa: E501
        :type: int
        """

        self._window_size = window_size

    @property
    def windowing(self):
        """Gets the windowing of this ChartSettings.  # noqa: E501

        For the tabular view, whether to use the full time window for the query or the last X minutes  # noqa: E501

        :return: The windowing of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._windowing

    @windowing.setter
    def windowing(self, windowing):
        """Sets the windowing of this ChartSettings.

        For the tabular view, whether to use the full time window for the query or the last X minutes  # noqa: E501

        :param windowing: The windowing of this ChartSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["full", "last"]  # noqa: E501
        if (self._configuration.client_side_validation and
                windowing not in allowed_values):
            raise ValueError(
                "Invalid value for `windowing` ({0}), must be one of {1}"  # noqa: E501
                .format(windowing, allowed_values)
            )

        self._windowing = windowing

    @property
    def xmax(self):
        """Gets the xmax of this ChartSettings.  # noqa: E501

        For x-y scatterplots, max value for X-axis.  Set null for auto  # noqa: E501

        :return: The xmax of this ChartSettings.  # noqa: E501
        :rtype: float
        """
        return self._xmax

    @xmax.setter
    def xmax(self, xmax):
        """Sets the xmax of this ChartSettings.

        For x-y scatterplots, max value for X-axis.  Set null for auto  # noqa: E501

        :param xmax: The xmax of this ChartSettings.  # noqa: E501
        :type: float
        """

        self._xmax = xmax

    @property
    def xmin(self):
        """Gets the xmin of this ChartSettings.  # noqa: E501

        For x-y scatterplots, min value for X-axis.  Set null for auto  # noqa: E501

        :return: The xmin of this ChartSettings.  # noqa: E501
        :rtype: float
        """
        return self._xmin

    @xmin.setter
    def xmin(self, xmin):
        """Sets the xmin of this ChartSettings.

        For x-y scatterplots, min value for X-axis.  Set null for auto  # noqa: E501

        :param xmin: The xmin of this ChartSettings.  # noqa: E501
        :type: float
        """

        self._xmin = xmin

    @property
    def y0_scale_si_by1024(self):
        """Gets the y0_scale_si_by1024 of this ChartSettings.  # noqa: E501

        Default: false. Whether to scale numerical magnitude labels for left Y-axis by 1024 in the IEC/Binary manner (instead of by 1000 like SI)  # noqa: E501

        :return: The y0_scale_si_by1024 of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._y0_scale_si_by1024

    @y0_scale_si_by1024.setter
    def y0_scale_si_by1024(self, y0_scale_si_by1024):
        """Sets the y0_scale_si_by1024 of this ChartSettings.

        Default: false. Whether to scale numerical magnitude labels for left Y-axis by 1024 in the IEC/Binary manner (instead of by 1000 like SI)  # noqa: E501

        :param y0_scale_si_by1024: The y0_scale_si_by1024 of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._y0_scale_si_by1024 = y0_scale_si_by1024

    @property
    def y0_unit_autoscaling(self):
        """Gets the y0_unit_autoscaling of this ChartSettings.  # noqa: E501

        Default: false. Whether to automatically adjust magnitude labels and units for the left Y-axis to favor smaller magnitudes and larger units  # noqa: E501

        :return: The y0_unit_autoscaling of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._y0_unit_autoscaling

    @y0_unit_autoscaling.setter
    def y0_unit_autoscaling(self, y0_unit_autoscaling):
        """Sets the y0_unit_autoscaling of this ChartSettings.

        Default: false. Whether to automatically adjust magnitude labels and units for the left Y-axis to favor smaller magnitudes and larger units  # noqa: E501

        :param y0_unit_autoscaling: The y0_unit_autoscaling of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._y0_unit_autoscaling = y0_unit_autoscaling

    @property
    def y1_max(self):
        """Gets the y1_max of this ChartSettings.  # noqa: E501

        For plots with multiple Y-axes, max value for right-side Y-axis.  Set null for auto  # noqa: E501

        :return: The y1_max of this ChartSettings.  # noqa: E501
        :rtype: float
        """
        return self._y1_max

    @y1_max.setter
    def y1_max(self, y1_max):
        """Sets the y1_max of this ChartSettings.

        For plots with multiple Y-axes, max value for right-side Y-axis.  Set null for auto  # noqa: E501

        :param y1_max: The y1_max of this ChartSettings.  # noqa: E501
        :type: float
        """

        self._y1_max = y1_max

    @property
    def y1_min(self):
        """Gets the y1_min of this ChartSettings.  # noqa: E501

        For plots with multiple Y-axes, min value for right-side Y-axis.  Set null for auto  # noqa: E501

        :return: The y1_min of this ChartSettings.  # noqa: E501
        :rtype: float
        """
        return self._y1_min

    @y1_min.setter
    def y1_min(self, y1_min):
        """Sets the y1_min of this ChartSettings.

        For plots with multiple Y-axes, min value for right-side Y-axis.  Set null for auto  # noqa: E501

        :param y1_min: The y1_min of this ChartSettings.  # noqa: E501
        :type: float
        """

        self._y1_min = y1_min

    @property
    def y1_scale_si_by1024(self):
        """Gets the y1_scale_si_by1024 of this ChartSettings.  # noqa: E501

        Default: false. Whether to scale numerical magnitude labels for right Y-axis by 1024 in the IEC/Binary manner (instead of by 1000 like SI)  # noqa: E501

        :return: The y1_scale_si_by1024 of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._y1_scale_si_by1024

    @y1_scale_si_by1024.setter
    def y1_scale_si_by1024(self, y1_scale_si_by1024):
        """Sets the y1_scale_si_by1024 of this ChartSettings.

        Default: false. Whether to scale numerical magnitude labels for right Y-axis by 1024 in the IEC/Binary manner (instead of by 1000 like SI)  # noqa: E501

        :param y1_scale_si_by1024: The y1_scale_si_by1024 of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._y1_scale_si_by1024 = y1_scale_si_by1024

    @property
    def y1_unit_autoscaling(self):
        """Gets the y1_unit_autoscaling of this ChartSettings.  # noqa: E501

        Default: false. Whether to automatically adjust magnitude labels and units for the right Y-axis to favor smaller magnitudes and larger units  # noqa: E501

        :return: The y1_unit_autoscaling of this ChartSettings.  # noqa: E501
        :rtype: bool
        """
        return self._y1_unit_autoscaling

    @y1_unit_autoscaling.setter
    def y1_unit_autoscaling(self, y1_unit_autoscaling):
        """Sets the y1_unit_autoscaling of this ChartSettings.

        Default: false. Whether to automatically adjust magnitude labels and units for the right Y-axis to favor smaller magnitudes and larger units  # noqa: E501

        :param y1_unit_autoscaling: The y1_unit_autoscaling of this ChartSettings.  # noqa: E501
        :type: bool
        """

        self._y1_unit_autoscaling = y1_unit_autoscaling

    @property
    def y1_units(self):
        """Gets the y1_units of this ChartSettings.  # noqa: E501

        For plots with multiple Y-axes, units for right-side Y-axis  # noqa: E501

        :return: The y1_units of this ChartSettings.  # noqa: E501
        :rtype: str
        """
        return self._y1_units

    @y1_units.setter
    def y1_units(self, y1_units):
        """Sets the y1_units of this ChartSettings.

        For plots with multiple Y-axes, units for right-side Y-axis  # noqa: E501

        :param y1_units: The y1_units of this ChartSettings.  # noqa: E501
        :type: str
        """

        self._y1_units = y1_units

    @property
    def ymax(self):
        """Gets the ymax of this ChartSettings.  # noqa: E501

        For x-y scatterplots, max value for Y-axis.  Set null for auto  # noqa: E501

        :return: The ymax of this ChartSettings.  # noqa: E501
        :rtype: float
        """
        return self._ymax

    @ymax.setter
    def ymax(self, ymax):
        """Sets the ymax of this ChartSettings.

        For x-y scatterplots, max value for Y-axis.  Set null for auto  # noqa: E501

        :param ymax: The ymax of this ChartSettings.  # noqa: E501
        :type: float
        """

        self._ymax = ymax

    @property
    def ymin(self):
        """Gets the ymin of this ChartSettings.  # noqa: E501

        For x-y scatterplots, min value for Y-axis.  Set null for auto  # noqa: E501

        :return: The ymin of this ChartSettings.  # noqa: E501
        :rtype: float
        """
        return self._ymin

    @ymin.setter
    def ymin(self, ymin):
        """Sets the ymin of this ChartSettings.

        For x-y scatterplots, min value for Y-axis.  Set null for auto  # noqa: E501

        :param ymin: The ymin of this ChartSettings.  # noqa: E501
        :type: float
        """

        self._ymin = ymin

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChartSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChartSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChartSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class TargetInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'method': 'str',
        'name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'method': 'method',
        'name': 'name'
    }

    def __init__(self, id=None, method=None, name=None, _configuration=None):  # noqa: E501
        """TargetInfo - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._method = None
        self._name = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if method is not None:
            self.method = method
        if name is not None:
            self.name = name

    @property
    def id(self):
        """Gets the id of this TargetInfo.  # noqa: E501

        ID of the alert target  # noqa: E501

        :return: The id of this TargetInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TargetInfo.

        ID of the alert target  # noqa: E501

        :param id: The id of this TargetInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def method(self):
        """Gets the method of this TargetInfo.  # noqa: E501

        Notification method of the alert target  # noqa: E501

        :return: The method of this TargetInfo.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this TargetInfo.

        Notification method of the alert target  # noqa: E501

        :param method: The method of this TargetInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["EMAIL", "PAGERDUTY", "WEBHOOK"]  # noqa: E501
        if (self._configuration.client_side_validation and
                method not in allowed_values):
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def name(self):
        """Gets the name of this TargetInfo.  # noqa: E501

        Name of the alert target  # noqa: E501

        :return: The name of this TargetInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TargetInfo.

        Name of the alert target  # noqa: E501

        :param name: The name of this TargetInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TargetInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TargetInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TargetInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class UserToCreate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email_address': 'str',
        'groups': 'list[str]',
        'ingestion_policy_id': 'str',
        'roles': 'list[str]',
        'user_groups': 'list[str]'
    }

    attribute_map = {
        'email_address': 'emailAddress',
        'groups': 'groups',
        'ingestion_policy_id': 'ingestionPolicyId',
        'roles': 'roles',
        'user_groups': 'userGroups'
    }

    def __init__(self, email_address=None, groups=None, ingestion_policy_id=None, roles=None, user_groups=None, _configuration=None):  # noqa: E501
        """UserToCreate - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._email_address = None
        self._groups = None
        self._ingestion_policy_id = None
        self._roles = None
        self._user_groups = None
        self.discriminator = None

        self.email_address = email_address
        self.groups = groups
        if ingestion_policy_id is not None:
            self.ingestion_policy_id = ingestion_policy_id
        if roles is not None:
            self.roles = roles
        self.user_groups = user_groups

    @property
    def email_address(self):
        """Gets the email_address of this UserToCreate.  # noqa: E501

        The (unique) identifier of the user to create. Must be a valid email address  # noqa: E501

        :return: The email_address of this UserToCreate.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this UserToCreate.

        The (unique) identifier of the user to create. Must be a valid email address  # noqa: E501

        :param email_address: The email_address of this UserToCreate.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and email_address is None:
            raise ValueError("Invalid value for `email_address`, must not be `None`")  # noqa: E501

        self._email_address = email_address

    @property
    def groups(self):
        """Gets the groups of this UserToCreate.  # noqa: E501

        List of permission groups to grant to this user. Please note that 'host_tag_management' is the equivalent of the 'Source Tag Management' permission.  Possible values are agent_management, alerts_management, dashboard_management, embedded_charts, events_management, external_links_management, host_tag_management, metrics_management, user_management  # noqa: E501

        :return: The groups of this UserToCreate.  # noqa: E501
        :rtype: list[str]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this UserToCreate.

        List of permission groups to grant to this user. Please note that 'host_tag_management' is the equivalent of the 'Source Tag Management' permission.  Possible values are agent_management, alerts_management, dashboard_management, embedded_charts, events_management, external_links_management, host_tag_management, metrics_management, user_management  # noqa: E501

        :param groups: The groups of this UserToCreate.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and groups is None:
            raise ValueError("Invalid value for `groups`, must not be `None`")  # noqa: E501

        self._groups = groups

    @property
    def ingestion_policy_id(self):
        """Gets the ingestion_policy_id of this UserToCreate.  # noqa: E501

        The identifier of the ingestion policy linked with user.  # noqa: E501

        :return: The ingestion_policy_id of this UserToCreate.  # noqa: E501
        :rtype: str
        """
        return self._ingestion_policy_id

    @ingestion_policy_id.setter
    def ingestion_policy_id(self, ingestion_policy_id):
        """Sets the ingestion_policy_id of this UserToCreate.

        The identifier of the ingestion policy linked with user.  # noqa: E501

        :param ingestion_policy_id: The ingestion_policy_id of this UserToCreate.  # noqa: E501
        :type: str
        """

        self._ingestion_policy_id = ingestion_policy_id

    @property
    def roles(self):
        """Gets the roles of this UserToCreate.  # noqa: E501

        The list of role ids, the user will be added to.\"  # noqa: E501

        :return: The roles of this UserToCreate.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this UserToCreate.

        The list of role ids, the user will be added to.\"  # noqa: E501

        :param roles: The roles of this UserToCreate.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def user_groups(self):
        """Gets the user_groups of this UserToCreate.  # noqa: E501

        List of user groups to this user.   # noqa: E501

        :return: The user_groups of this UserToCreate.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        """Sets the user_groups of this UserToCreate.

        List of user groups to this user.   # noqa: E501

        :param user_groups: The user_groups of this UserToCreate.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and user_groups is None:
            raise ValueError("Invalid value for `user_groups`, must not be `None`")  # noqa: E501

        self._user_groups = user_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserToCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserToCreate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserToCreate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class UserModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer': 'str',
        'groups': 'list[str]',
        'identifier': 'str',
        'ingestion_policy': 'IngestionPolicy',
        'last_successful_login': 'int',
        'roles': 'list[RoleDTO]',
        'sso_id': 'str',
        'user_groups': 'list[UserGroup]'
    }

    attribute_map = {
        'customer': 'customer',
        'groups': 'groups',
        'identifier': 'identifier',
        'ingestion_policy': 'ingestionPolicy',
        'last_successful_login': 'lastSuccessfulLogin',
        'roles': 'roles',
        'sso_id': 'ssoId',
        'user_groups': 'userGroups'
    }

    def __init__(self, customer=None, groups=None, identifier=None, ingestion_policy=None, last_successful_login=None, roles=None, sso_id=None, user_groups=None, _configuration=None):  # noqa: E501
        """UserModel - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer = None
        self._groups = None
        self._identifier = None
        self._ingestion_policy = None
        self._last_successful_login = None
        self._roles = None
        self._sso_id = None
        self._user_groups = None
        self.discriminator = None

        self.customer = customer
        self.groups = groups
        self.identifier = identifier
        if ingestion_policy is not None:
            self.ingestion_policy = ingestion_policy
        if last_successful_login is not None:
            self.last_successful_login = last_successful_login
        if roles is not None:
            self.roles = roles
        if sso_id is not None:
            self.sso_id = sso_id
        self.user_groups = user_groups

    @property
    def customer(self):
        """Gets the customer of this UserModel.  # noqa: E501

        The id of the customer to which this user belongs  # noqa: E501

        :return: The customer of this UserModel.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this UserModel.

        The id of the customer to which this user belongs  # noqa: E501

        :param customer: The customer of this UserModel.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and customer is None:
            raise ValueError("Invalid value for `customer`, must not be `None`")  # noqa: E501

        self._customer = customer

    @property
    def groups(self):
        """Gets the groups of this UserModel.  # noqa: E501

        The permissions granted to this user  # noqa: E501

        :return: The groups of this UserModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this UserModel.

        The permissions granted to this user  # noqa: E501

        :param groups: The groups of this UserModel.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and groups is None:
            raise ValueError("Invalid value for `groups`, must not be `None`")  # noqa: E501

        self._groups = groups

    @property
    def identifier(self):
        """Gets the identifier of this UserModel.  # noqa: E501

        The unique identifier of this user, which must be their valid email address  # noqa: E501

        :return: The identifier of this UserModel.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this UserModel.

        The unique identifier of this user, which must be their valid email address  # noqa: E501

        :param identifier: The identifier of this UserModel.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and identifier is None:
            raise ValueError("Invalid value for `identifier`, must not be `None`")  # noqa: E501

        self._identifier = identifier

    @property
    def ingestion_policy(self):
        """Gets the ingestion_policy of this UserModel.  # noqa: E501


        :return: The ingestion_policy of this UserModel.  # noqa: E501
        :rtype: IngestionPolicy
        """
        return self._ingestion_policy

    @ingestion_policy.setter
    def ingestion_policy(self, ingestion_policy):
        """Sets the ingestion_policy of this UserModel.


        :param ingestion_policy: The ingestion_policy of this UserModel.  # noqa: E501
        :type: IngestionPolicy
        """

        self._ingestion_policy = ingestion_policy

    @property
    def last_successful_login(self):
        """Gets the last_successful_login of this UserModel.  # noqa: E501


        :return: The last_successful_login of this UserModel.  # noqa: E501
        :rtype: int
        """
        return self._last_successful_login

    @last_successful_login.setter
    def last_successful_login(self, last_successful_login):
        """Sets the last_successful_login of this UserModel.


        :param last_successful_login: The last_successful_login of this UserModel.  # noqa: E501
        :type: int
        """

        self._last_successful_login = last_successful_login

    @property
    def roles(self):
        """Gets the roles of this UserModel.  # noqa: E501


        :return: The roles of this UserModel.  # noqa: E501
        :rtype: list[RoleDTO]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this UserModel.


        :param roles: The roles of this UserModel.  # noqa: E501
        :type: list[RoleDTO]
        """

        self._roles = roles

    @property
    def sso_id(self):
        """Gets the sso_id of this UserModel.  # noqa: E501


        :return: The sso_id of this UserModel.  # noqa: E501
        :rtype: str
        """
        return self._sso_id

    @sso_id.setter
    def sso_id(self, sso_id):
        """Sets the sso_id of this UserModel.


        :param sso_id: The sso_id of this UserModel.  # noqa: E501
        :type: str
        """

        self._sso_id = sso_id

    @property
    def user_groups(self):
        """Gets the user_groups of this UserModel.  # noqa: E501

        The list of user groups the user belongs to  # noqa: E501

        :return: The user_groups of this UserModel.  # noqa: E501
        :rtype: list[UserGroup]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        """Sets the user_groups of this UserModel.

        The list of user groups the user belongs to  # noqa: E501

        :param user_groups: The user_groups of this UserModel.  # noqa: E501
        :type: list[UserGroup]
        """
        if self._configuration.client_side_validation and user_groups is None:
            raise ValueError("Invalid value for `user_groups`, must not be `None`")  # noqa: E501

        self._user_groups = user_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserModel):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class HistoryEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'change_description': 'list[str]',
        'id': 'str',
        'in_trash': 'bool',
        'update_time': 'int',
        'update_user': 'str',
        'version': 'int'
    }

    attribute_map = {
        'change_description': 'changeDescription',
        'id': 'id',
        'in_trash': 'inTrash',
        'update_time': 'updateTime',
        'update_user': 'updateUser',
        'version': 'version'
    }

    def __init__(self, change_description=None, id=None, in_trash=None, update_time=None, update_user=None, version=None, _configuration=None):  # noqa: E501
        """HistoryEntry - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._change_description = None
        self._id = None
        self._in_trash = None
        self._update_time = None
        self._update_user = None
        self._version = None
        self.discriminator = None

        if change_description is not None:
            self.change_description = change_description
        if id is not None:
            self.id = id
        if in_trash is not None:
            self.in_trash = in_trash
        if update_time is not None:
            self.update_time = update_time
        if update_user is not None:
            self.update_user = update_user
        if version is not None:
            self.version = version

    @property
    def change_description(self):
        """Gets the change_description of this HistoryEntry.  # noqa: E501


        :return: The change_description of this HistoryEntry.  # noqa: E501
        :rtype: list[str]
        """
        return self._change_description

    @change_description.setter
    def change_description(self, change_description):
        """Sets the change_description of this HistoryEntry.


        :param change_description: The change_description of this HistoryEntry.  # noqa: E501
        :type: list[str]
        """

        self._change_description = change_description

    @property
    def id(self):
        """Gets the id of this HistoryEntry.  # noqa: E501


        :return: The id of this HistoryEntry.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HistoryEntry.


        :param id: The id of this HistoryEntry.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def in_trash(self):
        """Gets the in_trash of this HistoryEntry.  # noqa: E501


        :return: The in_trash of this HistoryEntry.  # noqa: E501
        :rtype: bool
        """
        return self._in_trash

    @in_trash.setter
    def in_trash(self, in_trash):
        """Sets the in_trash of this HistoryEntry.


        :param in_trash: The in_trash of this HistoryEntry.  # noqa: E501
        :type: bool
        """

        self._in_trash = in_trash

    @property
    def update_time(self):
        """Gets the update_time of this HistoryEntry.  # noqa: E501


        :return: The update_time of this HistoryEntry.  # noqa: E501
        :rtype: int
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this HistoryEntry.


        :param update_time: The update_time of this HistoryEntry.  # noqa: E501
        :type: int
        """

        self._update_time = update_time

    @property
    def update_user(self):
        """Gets the update_user of this HistoryEntry.  # noqa: E501


        :return: The update_user of this HistoryEntry.  # noqa: E501
        :rtype: str
        """
        return self._update_user

    @update_user.setter
    def update_user(self, update_user):
        """Sets the update_user of this HistoryEntry.


        :param update_user: The update_user of this HistoryEntry.  # noqa: E501
        :type: str
        """

        self._update_user = update_user

    @property
    def version(self):
        """Gets the version of this HistoryEntry.  # noqa: E501


        :return: The version of this HistoryEntry.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this HistoryEntry.


        :param version: The version of this HistoryEntry.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HistoryEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoryEntry):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HistoryEntry):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class ProxyApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_proxy(self, id, **kwargs):  # noqa: E501
        """Delete a specific proxy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_proxy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param bool skip_trash:
        :return: ResponseContainerProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_proxy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_proxy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_proxy_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a specific proxy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_proxy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param bool skip_trash:
        :return: ResponseContainerProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'skip_trash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_proxy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_proxy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'skip_trash' in params:
            query_params.append(('skipTrash', params['skip_trash']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/proxy/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerProxy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_proxy(self, **kwargs):  # noqa: E501
        """Get all proxies for a customer  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_proxy(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_proxy_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_proxy_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_proxy_with_http_info(self, **kwargs):  # noqa: E501
        """Get all proxies for a customer  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_proxy_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset:
        :param int limit:
        :return: ResponseContainerPagedProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_proxy" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/proxy', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerPagedProxy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_proxy(self, id, **kwargs):  # noqa: E501
        """Get a specific proxy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_proxy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_proxy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_proxy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_proxy_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a specific proxy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_proxy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_proxy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_proxy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/proxy/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerProxy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def undelete_proxy(self, id, **kwargs):  # noqa: E501
        """Undelete a specific proxy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.undelete_proxy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.undelete_proxy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.undelete_proxy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def undelete_proxy_with_http_info(self, id, **kwargs):  # noqa: E501
        """Undelete a specific proxy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.undelete_proxy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method undelete_proxy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `undelete_proxy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/proxy/{id}/undelete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerProxy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_proxy(self, id, **kwargs):  # noqa: E501
        """Update the name of a specific proxy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_proxy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param Proxy body: Example Body:  <pre>{   \"name\": \"New Name for proxy\" }</pre>
        :return: ResponseContainerProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_proxy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_proxy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_proxy_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update the name of a specific proxy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_proxy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param Proxy body: Example Body:  <pre>{   \"name\": \"New Name for proxy\" }</pre>
        :return: ResponseContainerProxy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_proxy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_proxy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/proxy/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerProxy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.anomaly_api import AnomalyApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestAnomalyApi(unittest.TestCase):
    """AnomalyApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.anomaly_api.AnomalyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_anomalies(self):
        """Test case for get_all_anomalies

        Get all anomalies for a customer during a time interval  # noqa: E501
        """
        pass

    def test_get_anomalies_for_chart_and_param_hash(self):
        """Test case for get_anomalies_for_chart_and_param_hash

        Get all anomalies for a chart with a set of dashboard parameters during a time interval  # noqa: E501
        """
        pass

    def test_get_chart_anomalies_for_chart(self):
        """Test case for get_chart_anomalies_for_chart

        Get all anomalies for a chart during a time interval  # noqa: E501
        """
        pass

    def test_get_chart_anomalies_of_one_dashboard(self):
        """Test case for get_chart_anomalies_of_one_dashboard

        Get all anomalies for a dashboard that does not have any dashboard parameters during a time interval  # noqa: E501
        """
        pass

    def test_get_dashboard_anomalies(self):
        """Test case for get_dashboard_anomalies

        Get all anomalies for a dashboard with a particular set of dashboard parameters as identified by paramHash, during a time interval  # noqa: E501
        """
        pass

    def test_get_related_anomalies(self):
        """Test case for get_related_anomalies

        Get all related anomalies for a firing event with a time span  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class SortableSearchRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'limit': 'int',
        'offset': 'int',
        'query': 'list[SearchQuery]',
        'sort': 'Sorting'
    }

    attribute_map = {
        'limit': 'limit',
        'offset': 'offset',
        'query': 'query',
        'sort': 'sort'
    }

    def __init__(self, limit=None, offset=None, query=None, sort=None, _configuration=None):  # noqa: E501
        """SortableSearchRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._limit = None
        self._offset = None
        self._query = None
        self._sort = None
        self.discriminator = None

        if limit is not None:
            self.limit = limit
        if offset is not None:
            self.offset = offset
        if query is not None:
            self.query = query
        if sort is not None:
            self.sort = sort

    @property
    def limit(self):
        """Gets the limit of this SortableSearchRequest.  # noqa: E501

        The number of results to return.  Default: 100, Maximum allowed: 1000  # noqa: E501

        :return: The limit of this SortableSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this SortableSearchRequest.

        The number of results to return.  Default: 100, Maximum allowed: 1000  # noqa: E501

        :param limit: The limit of this SortableSearchRequest.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                limit is not None and limit > 1000):  # noqa: E501
            raise ValueError("Invalid value for `limit`, must be a value less than or equal to `1000`")  # noqa: E501
        if (self._configuration.client_side_validation and
                limit is not None and limit < 1):  # noqa: E501
            raise ValueError("Invalid value for `limit`, must be a value greater than or equal to `1`")  # noqa: E501

        self._limit = limit

    @property
    def offset(self):
        """Gets the offset of this SortableSearchRequest.  # noqa: E501

        The number of results to skip before returning values.  Default: 0  # noqa: E501

        :return: The offset of this SortableSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this SortableSearchRequest.

        The number of results to skip before returning values.  Default: 0  # noqa: E501

        :param offset: The offset of this SortableSearchRequest.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def query(self):
        """Gets the query of this SortableSearchRequest.  # noqa: E501

        A list of queries by which to limit the search results.  Entities that match ALL queries in the list are returned  # noqa: E501

        :return: The query of this SortableSearchRequest.  # noqa: E501
        :rtype: list[SearchQuery]
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this SortableSearchRequest.

        A list of queries by which to limit the search results.  Entities that match ALL queries in the list are returned  # noqa: E501

        :param query: The query of this SortableSearchRequest.  # noqa: E501
        :type: list[SearchQuery]
        """

        self._query = query

    @property
    def sort(self):
        """Gets the sort of this SortableSearchRequest.  # noqa: E501


        :return: The sort of this SortableSearchRequest.  # noqa: E501
        :rtype: Sorting
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this SortableSearchRequest.


        :param sort: The sort of this SortableSearchRequest.  # noqa: E501
        :type: Sorting
        """

        self._sort = sort

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SortableSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SortableSearchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SortableSearchRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class AccessPolicyApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_access_policy(self, **kwargs):  # noqa: E501
        """Get the access policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_access_policy(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResponseContainerAccessPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_access_policy_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_access_policy_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_access_policy_with_http_info(self, **kwargs):  # noqa: E501
        """Get the access policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_access_policy_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResponseContainerAccessPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_access_policy" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/accesspolicy', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerAccessPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_access_policy(self, **kwargs):  # noqa: E501
        """Update the access policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_access_policy(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessPolicy body: Example Body:  <pre>{  \"policyRules\": [{    \"name\": \"rule name\",    \"description\": \"desc\",    \"action\": \"ALLOW\",    \"subnet\": \"12.148.72.0/23\"  }] }</pre>
        :return: ResponseContainerAccessPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_access_policy_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.update_access_policy_with_http_info(**kwargs)  # noqa: E501
            return data

    def update_access_policy_with_http_info(self, **kwargs):  # noqa: E501
        """Update the access policy  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_access_policy_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessPolicy body: Example Body:  <pre>{  \"policyRules\": [{    \"name\": \"rule name\",    \"description\": \"desc\",    \"action\": \"ALLOW\",    \"subnet\": \"12.148.72.0/23\"  }] }</pre>
        :return: ResponseContainerAccessPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_access_policy" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/accesspolicy', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerAccessPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def validate_url(self, **kwargs):  # noqa: E501
        """Validate a given url and ip address  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_url(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ip:
        :return: ResponseContainerAccessPolicyAction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.validate_url_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.validate_url_with_http_info(**kwargs)  # noqa: E501
            return data

    def validate_url_with_http_info(self, **kwargs):  # noqa: E501
        """Validate a given url and ip address  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_url_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ip:
        :return: ResponseContainerAccessPolicyAction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ip']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_url" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ip' in params:
            query_params.append(('ip', params['ip']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/accesspolicy/validate', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerAccessPolicyAction',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class AccessPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer': 'str',
        'last_updated_ms': 'int',
        'policy_rules': 'list[AccessPolicyRuleDTO]'
    }

    attribute_map = {
        'customer': 'customer',
        'last_updated_ms': 'lastUpdatedMs',
        'policy_rules': 'policyRules'
    }

    def __init__(self, customer=None, last_updated_ms=None, policy_rules=None, _configuration=None):  # noqa: E501
        """AccessPolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer = None
        self._last_updated_ms = None
        self._policy_rules = None
        self.discriminator = None

        if customer is not None:
            self.customer = customer
        if last_updated_ms is not None:
            self.last_updated_ms = last_updated_ms
        if policy_rules is not None:
            self.policy_rules = policy_rules

    @property
    def customer(self):
        """Gets the customer of this AccessPolicy.  # noqa: E501


        :return: The customer of this AccessPolicy.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this AccessPolicy.


        :param customer: The customer of this AccessPolicy.  # noqa: E501
        :type: str
        """

        self._customer = customer

    @property
    def last_updated_ms(self):
        """Gets the last_updated_ms of this AccessPolicy.  # noqa: E501


        :return: The last_updated_ms of this AccessPolicy.  # noqa: E501
        :rtype: int
        """
        return self._last_updated_ms

    @last_updated_ms.setter
    def last_updated_ms(self, last_updated_ms):
        """Sets the last_updated_ms of this AccessPolicy.


        :param last_updated_ms: The last_updated_ms of this AccessPolicy.  # noqa: E501
        :type: int
        """

        self._last_updated_ms = last_updated_ms

    @property
    def policy_rules(self):
        """Gets the policy_rules of this AccessPolicy.  # noqa: E501


        :return: The policy_rules of this AccessPolicy.  # noqa: E501
        :rtype: list[AccessPolicyRuleDTO]
        """
        return self._policy_rules

    @policy_rules.setter
    def policy_rules(self, policy_rules):
        """Sets the policy_rules of this AccessPolicy.


        :param policy_rules: The policy_rules of this AccessPolicy.  # noqa: E501
        :type: list[AccessPolicyRuleDTO]
        """

        self._policy_rules = policy_rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccessPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccessPolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class AccessControlListReadDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'entity_id': 'str',
        'modify_acl': 'list[AccessControlElement]',
        'view_acl': 'list[AccessControlElement]'
    }

    attribute_map = {
        'entity_id': 'entityId',
        'modify_acl': 'modifyAcl',
        'view_acl': 'viewAcl'
    }

    def __init__(self, entity_id=None, modify_acl=None, view_acl=None, _configuration=None):  # noqa: E501
        """AccessControlListReadDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._entity_id = None
        self._modify_acl = None
        self._view_acl = None
        self.discriminator = None

        if entity_id is not None:
            self.entity_id = entity_id
        if modify_acl is not None:
            self.modify_acl = modify_acl
        if view_acl is not None:
            self.view_acl = view_acl

    @property
    def entity_id(self):
        """Gets the entity_id of this AccessControlListReadDTO.  # noqa: E501

        The entity Id  # noqa: E501

        :return: The entity_id of this AccessControlListReadDTO.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this AccessControlListReadDTO.

        The entity Id  # noqa: E501

        :param entity_id: The entity_id of this AccessControlListReadDTO.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def modify_acl(self):
        """Gets the modify_acl of this AccessControlListReadDTO.  # noqa: E501

        List of users and user groups ids that have modify permission  # noqa: E501

        :return: The modify_acl of this AccessControlListReadDTO.  # noqa: E501
        :rtype: list[AccessControlElement]
        """
        return self._modify_acl

    @modify_acl.setter
    def modify_acl(self, modify_acl):
        """Sets the modify_acl of this AccessControlListReadDTO.

        List of users and user groups ids that have modify permission  # noqa: E501

        :param modify_acl: The modify_acl of this AccessControlListReadDTO.  # noqa: E501
        :type: list[AccessControlElement]
        """

        self._modify_acl = modify_acl

    @property
    def view_acl(self):
        """Gets the view_acl of this AccessControlListReadDTO.  # noqa: E501

        List of users and user group ids that have view permission  # noqa: E501

        :return: The view_acl of this AccessControlListReadDTO.  # noqa: E501
        :rtype: list[AccessControlElement]
        """
        return self._view_acl

    @view_acl.setter
    def view_acl(self, view_acl):
        """Sets the view_acl of this AccessControlListReadDTO.

        List of users and user group ids that have view permission  # noqa: E501

        :param view_acl: The view_acl of this AccessControlListReadDTO.  # noqa: E501
        :type: list[AccessControlElement]
        """

        self._view_acl = view_acl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccessControlListReadDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessControlListReadDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccessControlListReadDTO):
            return True

        return self.to_dict() != other.to_dict()
